# Changelog

## [0.2.11a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.2.11a1) (2024-11-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.2.10...0.2.11a1)

**Merged pull requests:**

- Update combo-lock requirement from \<0.3,\>=0.2.2 to \>=0.2.2,\<0.4 in /requirements [\#585](https://github.com/OpenVoiceOS/ovos-core/pull/585) ([dependabot[bot]](https://github.com/apps/dependabot))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
